@import url("test.css");

body {
  background: #fafafa url("/images/bg.png");
}

#header {
  margin: 0;
  padding: 0;
  height: 5em;
}

.content {
  /*background-color: white;*/
  /*font-size: smaller;*/
  font-size: 95%;
  clear: both;
  padding: 0px;
  margin: 0px;
  margin-left: 180px;
  margin-top: 6em;
}

ol li
{
  margin-bottom: 1em;
}

/*
 * Optional table styles
 *
 */
th.minor    { font-style: italic; padding: 3px; text-align: left; }
th.centre   { text-align: center; }
td.border   { border-bottom: 1px dotted #DFDFDF; }
td.left     { text-align: left; }
td.right    { text-align: right; }
