

/******************************
  list styles
  *************************/

dl
{
  margin: 1em 3em 1em 3em;
}

dt
{
  /*color: #2071CC;
  font-size: 105%;*/
}

dd
{
  margin: 0 0 1em 1em;
}


hr
{
  height: 1px;
  border-top: 1px solid #4a54ff;
  border-bottom: none;
  border-left: none;
  border-right: none;
  margin: 0px auto;
  width: 80%;
}

